enumFindingRule
enum FindingRule: string
Restricted visibility: declared "@visibility root". Code outside that scope must not name this declaration.
What a finding says about a catalogued statement.
Cases
case UnresolvedSql = 'unresolved-sql'case DynamicSql = 'dynamic-sql'case ExternalInput = 'external-input'case PlaceholderCountMismatch = 'placeholder-count-mismatch'case AnalysisIncomplete = 'analysis-incomplete'case CallNotAnalyzed = 'call-not-analyzed'Methods
public function severity(): SeverityHow much attention findings of this rule deserve by default.
Returns
Test cases 1
Called from 2
Calls 9
- class-const FindingRule::ExternalInput() line 27
- class-const Severity::High() line 27
- class-const FindingRule::DynamicSql() line 28
- class-const Severity::Medium() line 28
- class-const FindingRule::PlaceholderCountMismatch() line 29
- class-const FindingRule::UnresolvedSql() line 30
- class-const Severity::Low() line 30
- class-const FindingRule::AnalysisIncomplete() line 31
- class-const FindingRule::CallNotAnalyzed() line 32
public function describe(): stringA one-line explanation of what the rule reports.
Returns
stringTest cases 1
Called from 1
Calls 6
- class-const FindingRule::UnresolvedSql() line 42
- class-const FindingRule::DynamicSql() line 43
- class-const FindingRule::ExternalInput() line 44
- class-const FindingRule::PlaceholderCountMismatch() line 45
- class-const FindingRule::AnalysisIncomplete() line 46
- class-const FindingRule::CallNotAnalyzed() line 47
Test cases 63
Test cases that cover or call this symbol, from the coverage report and from the analyzed test sources.
Dedicated tests 3
Other tests reaching this symbol 60
CatalogCommandTestcallsEntryFactoryTest::testBuildOneReportsAStatementBoundWithTheWrongNumberOfValuescallsEntryFactoryTest::testBuildReportsAStatementBoundWithTheWrongNumberOfValuescallsEntryFactoryTest::testCountMismatchStaysQuietWhenTheCallSiteHasAlternativescallsEntryFactoryTest::testFindingsReportACallNotAnalyzedWithoutClaimingALimitCutItShortcallsEntryFactoryTest::testFindingsReportADynamicStatementcallsEntryFactoryTest::testFindingsReportAnIncompleteSearchOnceEvenWhenALimitAlsoCutItShortcallsEntryFactoryTest::testFindingsReportAReadingALimitCutShortAlongsideAWrongCountcallsEntryFactoryTest::testFindingsReportAStatementBoundWithTheWrongNumberOfValuescallsEntryFactoryTest::testFindingsReportAStatementThatDidNotResolveAtAllcallsEntryFactoryTest::testFindingsReportExternalInputcallsEntryFactoryTest::testFindingsReportExternalInputOnceHoweverManyValuesCarryItcallsEntryFactoryTest::testFindingsReportThatTheSearchDidNotClosecallsCatalogEntryTest::testHasFindingLooksForOneRulecallsCatalogEntryTest::testSeverityIsTheHighestOfTheFindingscallsFindingTest::testOfTakesTheSeverityOfTheRulecallsFindingTest::testTheSeverityCanBeStatedOutrightcallsCatalogFilterTest::testMatchesSeverityKeepsWhatIsAtLeastAsSeverecallsAnalyzerTest::testACallSiteSurvivesTheWalkNotReachingItcallsAnalyzerTest::testAValueBoundToOnePlaceholderStaysWithThatPlaceholdercallsCatalogIndexTest::testByRuleListsTheMostReportedRuleFirstcallsCatalogIndexTest::testHotspotsKeepCountingPastAStatementNothingWasReportedOncallsCatalogIndexTest::testHotspotsRankFunctionsByWhatWasReportedcallsCatalogIndexTest::testUsageCountsReadsWritesSchemaAndAttentioncallsCatalogStatisticsTest::testAtLeastCountsTheStatementsWorthLookingAtcallsCatalogStatisticsTest::testByRuleCountsTheFindingsMostFirstcallsCatalogStatisticsTest::testFilesSayWhatWasFoundInEachOfThemcallsCatalogStatisticsTest::testFindingsCountsEveryFindingOfEveryStatementcallsCatalogStatisticsTest::testFlaggedListsTheReportedStatementsWorstFirstcallsHtmlReporterTest::testRenderLinksEveryRouteToTheStatementsPagecallsHtmlReporterTest::testRenderWritesTheWholeSiteOfPagescallsClassPageTest::testRenderIsWrittenExactlycallsFileIndexPageTest::testRenderIsWrittenExactlycallsFilePageTest::testRenderIsWrittenExactlycallsFindingPageTest::testAnchorsNameTheHotspotsAndEveryRulecallsFindingPageTest::testHotspotsLinkEachFunctionAndAreSilentWhenNothingIsFlaggedcallsFindingPageTest::testRenderIsWrittenExactlycallsFindingPageTest::testRenderOpensWithWhereToLookAndThenListsEveryRulecallsFindingPageTest::testSectionHeadsTheRuleWithItsSeverityAndMeaningcallsNamespacePageTest::testRenderIsWrittenExactlycallsOverviewPageTest::testAttentionListsRulesAndTheFunctionsFlaggedMostcallsOverviewPageTest::testRenderIsWrittenExactlycallsOverviewPageTest::testRenderLaysOutEveryRouteToAStatementcallsStatementIndexPageTest::testRenderIsWrittenExactlycallsStatementPageTest::testFindingsCarryTheirRuleAndSeveritycallsStatementPageTest::testRenderCarriesEverythingKnownAboutTheStatementcallsStatementPageTest::testRenderIsWrittenExactlycallsStatementPageTest::testRenderOfACallNothingWasReadFromIsWrittenExactlycallsTableIndexPageTest::testRenderIsWrittenExactlycallsTableIndexPageTest::testRowCountsHowTheTableIsUsedAndMarksAGapInItsNamecallsTablePageTest::testRenderIsWrittenExactlycallsPageShellTest::testRenderIsWrittenExactlycallsStatementListTest::testFacetsIsWrittenExactlycallsStatementListTest::testFacetsOfferOnlyWhatWouldNarrowTheListingcallsStatementRowTest::testAttributesCarryEveryFactAListingIsNarrowedBycallsStatementRowTest::testAttributesNameARuleOnceHoweverOftenItWasReportedcallsStatementRowTest::testMetaNamesTheFunctionUnlessTheListingAlreadyDoescallsStatementRowTest::testMetaOmitsWhatTheListingAlreadyStatesAndShowsWhatIsNotOrdinarycallsJsonReporterTestcallsTextReporterTestcalls
Relations
Static calls 2
Method calls 3
- method-call SqlCatalog\Core\Catalog\Finding::of() packages/sql-catalog/src/Core/Catalog/Finding.php:31
- method-call SqlCatalog\Reporter\Html\Page\FindingPage::section() packages/sql-catalog/src/Reporter/Html/Page/FindingPage.php:98
- method-call SqlCatalog\Reporter\Html\Page\FindingPage::section() packages/sql-catalog/src/Reporter/Html/Page/FindingPage.php:101
Constant reads 7
- class-const SqlCatalog\Core\Analysis\EntryFactory::findings() packages/sql-catalog/src/Core/Analysis/EntryFactory.php:221
- class-const SqlCatalog\Core\Analysis\EntryFactory::findings() packages/sql-catalog/src/Core/Analysis/EntryFactory.php:225
- class-const SqlCatalog\Core\Analysis\EntryFactory::findings() packages/sql-catalog/src/Core/Analysis/EntryFactory.php:232
- class-const SqlCatalog\Core\Analysis\EntryFactory::findings() packages/sql-catalog/src/Core/Analysis/EntryFactory.php:241
- class-const SqlCatalog\Core\Analysis\EntryFactory::findings() packages/sql-catalog/src/Core/Analysis/EntryFactory.php:246
- class-const SqlCatalog\Core\Analysis\EntryFactory::findings() packages/sql-catalog/src/Core/Analysis/EntryFactory.php:250
- class-const SqlCatalog\Core\Analysis\EntryFactory::countMismatch() packages/sql-catalog/src/Core/Analysis/EntryFactory.php:295
Type declarations 4
- type SqlCatalog\Core\Catalog\CatalogEntry packages/sql-catalog/src/Core/Catalog/CatalogEntry.php:123
- type SqlCatalog\Core\Catalog\Finding packages/sql-catalog/src/Core/Catalog/Finding.php:20
- type SqlCatalog\Core\Catalog\Finding packages/sql-catalog/src/Core/Catalog/Finding.php:29
- type SqlCatalog\Reporter\Html\Page\FindingPage packages/sql-catalog/src/Reporter/Html/Page/FindingPage.php:93